@@ -1,6 +1,6 @@
 /* empty - run processes under pseudo-terminal sessions
  * 
- * Copyright (C) 2005-2009 Mikhail E. Zakharov
+ * Copyright (C) 2005-2012 Mikhail E. Zakharov
  * empty was written by Mikhail E. Zakharov. This software was based on the 
  * basic idea of pty version 4.0 Copyright (c) 1992, Daniel J. Bernstein, but
  * no code was ported from pty4.
@@ -105,7 +105,7 @@
 
 #define tmpdir "/tmp"
 #define program "empty"
-#define version "0.6.18b" 
+#define version "0.6.19b" 
 
 /* -------------------------------------------------------------------------- */
 static void usage(void);
@@ -568,9 +568,10 @@ int main (int argc, char *argv[]) {
 
 #endif
 
-#if defined(__SVR4)
+#if defined(__SVR4) || defined(__AIX)
 		/* Setup terminal parameters for Solaris to work under cron or java.
-		Thanks to "lang qiu" <qiulang@gmail.com> for the initial line of parameters */
+		Thanks to "lang qiu" <qiulang@gmail.com> for the initial line of parameters.
+	       	and the same for AIX 5.3 by Ralf Winkel */
 		tt.c_lflag = ISIG | ICANON | ECHOE | ECHOK | ECHOCTL | ECHOKE | IEXTEN; 
 		tt.c_oflag = TABDLY | OPOST;
 		tt.c_iflag = BRKINT | IGNPAR | ISTRIP | ICRNL | IXON | IMAXBEL;
